Aggregator.aggregator
=====================

.. automodule:: Aggregator.aggregator

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      aggregate
      init_connection
      unify_url_id
   
   

   
   
   

   
   
   



